package java.lang.management;

import sun.management.MemoryUsageCompositeData;
import javax.management.openmbean.CompositeData;

public class MemoryUsage
{
    private final long init;
    private final long used;
    private final long committed;
    private final long max;
    
    public MemoryUsage(long n, long lng, long n2, long lng2) {
        if (n < -1L) {
            throw new IllegalArgumentException("init parameter = " + n + " is negative but not -1.");
        }
        if (lng2 < -1L) {
            throw new IllegalArgumentException("max parameter = " + lng2 + " is negative but not -1.");
        }
        if (lng < 0L) {
            throw new IllegalArgumentException("used parameter = " + lng + " is negative.");
        }
        if (n2 < 0L) {
            throw new IllegalArgumentException("committed parameter = " + n2 + " is negative.");
        }
        if (lng > n2) {
            throw new IllegalArgumentException("used = " + lng + " should be <= committed = " + n2);
        }
        if (lng2 >= 0L && n2 > lng2) {
            throw new IllegalArgumentException("committed = " + n2 + " should be < max = " + lng2);
        }
        this.init = n;
        this.used = lng;
        this.committed = n2;
        this.max = lng2;
        return;
    }
    
    private MemoryUsage(CompositeData cd) {
        MemoryUsageCompositeData.validateCompositeData(cd);
        this.init = MemoryUsageCompositeData.getInit(cd);
        this.used = MemoryUsageCompositeData.getUsed(cd);
        this.committed = MemoryUsageCompositeData.getCommitted(cd);
        this.max = MemoryUsageCompositeData.getMax(cd);
    }
    
    public long getInit() {
        return this.init;
    }
    
    public long getUsed() {
        return this.used;
    }
    
    public long getCommitted() {
        return this.committed;
    }
    
    public long getMax() {
        return this.max;
    }
    
    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("init = " + this.init + "(" + (this.init >> 10) + "K) ");
        sb.append("used = " + this.used + "(" + (this.used >> 10) + "K) ");
        sb.append("committed = " + this.committed + "(" + (this.committed >> 10) + "K) ");
        sb.append("max = " + this.max + "(" + (this.max >> 10) + "K)");
        return sb.toString();
    }
    
    public static MemoryUsage from(CompositeData compositeData) {
        if (compositeData == null) {
            return null;
        }
        if ((compositeData instanceof MemoryUsageCompositeData)) {
            return ((MemoryUsageCompositeData)compositeData).getMemoryUsage();
        }
        return new MemoryUsage(compositeData);
    }
}
